@@ -45,7 +45,7 @@ import org.apache.commons.lang.StringUtils;
  * A utility class to convert the configuration properties into any type.
  *
  * @author Emmanuel Bourg
- * @version $Id: PropertyConverter.java 1301990 2012-03-17 20:10:46Z oheger $
+ * @version $Id: PropertyConverter.java 1534376 2013-10-21 21:14:18Z henning $
  * @since 1.1
  */
 public final class PropertyConverter
@@ -106,6 +106,10 @@ public final class PropertyConverter
         {
             return toBoolean(value);
         }
+        else if (Character.class.equals(cls) || Character.TYPE.equals(cls))
+        {
+            return toCharacter(value);
+        }
         else if (Number.class.isAssignableFrom(cls) || cls.isPrimitive())
         {
             if (Integer.class.equals(cls) || Integer.TYPE.equals(cls))
@@ -212,6 +216,32 @@ public final class PropertyConverter
         }
     }
 
+    /**
+     * Converts the specified value object to a {@code Character}. This method
+     * converts the passed in object to a string. If the string has exactly one
+     * character, this character is returned as result. Otherwise, conversion
+     * fails.
+     *
+     * @param value the value to be converted
+     * @return the resulting {@code Character} object
+     * @throws ConversionException if the conversion is not possible
+     */
+    public static Character toCharacter(Object value) throws ConversionException
+    {
+        String strValue = String.valueOf(value);
+        if (strValue.length() == 1)
+        {
+            return Character.valueOf(strValue.charAt(0));
+        }
+        else
+        {
+            throw new ConversionException(
+                    String.format(
+                            "The value '%s' cannot be converted to a Character object!",
+                            strValue));
+        }
+    }
+
     /**
      * Convert the specified object into a Byte.
      *
